Python: module Gui

Gui | index /home/downey/swampy/trunk/python2/Gui.py

`This module is part of Swampy, a suite of programs available from
allendowney.com/swampy.
Copyright 2005 Allen B. Downey
Distributed under the GNU General Public License at gnu.org/licenses/gpl.html.
Wrapper classes for use with tkinter.
This module provides the following classes:
Gui: a sublass of Tk that provides wrappers for most of the
widget-creating methods from Tk. The advantage of these wrappers is
that they use Python's optional argument capability to provide
appropriate default values, and that they combine widget creation and
packing into a single step. They also eliminate the need to name the
parent widget explicitly by keeping track of a current frame and
packing new objects into it.
GuiCanvas: a subclass of Canvas that provides wrappers for most of the
item-creating methods from Canvas. The advantage of the wrappers
is, again, that they use optional arguments to provide appropriate
defaults, and that they perform coordinate transformations.
Transform: an abstract class that provides basic methods inherited
by CanvasTransform and the other transforms.
CanvasTransform: a transformation that maps standard Cartesian
coordinates onto the 'graphics' coordinates used by Canvas objects.
Callable: the standard recipe from Python Cookbook for encapsulating
a function and its arguments in an object that can be used as a
callback.
The most important idea in this module is using a stack of frames to
avoid keeping track of parent widgets explicitly.
WIDGET WRAPPERS:
The Gui class contains wrappers for the widgets in tkinter.
All of the wrappers invoke widget() to create and pack the new widget.
The first four positional
arguments determine how the widget is packed. Some widgets
take additional positional arguments. In most cases, the
keyword arguments are passed as options to the widget
constructor.
Widgets that use these defaults can just pass along
args and options unmolested. Widgets (like fr and en)
that want different defaults have to roll the arguments
in with the other options and then underride them
(underride means set only if not already set).
ITEM WRAPPERS:
GuiCanvas provides wrappers for the canvas item methods.`

Modules
`` |  |
Tkinter | math | sys | tkFont

Classes
`` |  | Tkinter.Canvas(Tkinter.Widget, Tkinter.XView, Tkinter.YView) GuiCanvas Tkinter.Tk(Tkinter.Misc, Tkinter.Wm) Gui __builtin__.list(__builtin__.object) BBox Point __builtin__.object Callable Item Transform CanvasTransform RotateTransform SwirlTransform ScaleTransform
class BBox(__builtin__.list)
`` | `List of coordinates, where each coordinate is a pair or a Point. The first coordinate is the upper-left corner; the second pair is the lower-right. Assumes pixel coordinates; that is, a higher y-value is lower. Creating a new bounding box makes a _shallow_ copy of the list of coordinates. For a deep copy, use Bbox.copy().`
| Method resolution order: BBox __builtin__.list __builtin__.object Methods defined here: center(self) `Returns the midpoint of the bbox as a Point object.` copy(self) flatten(self) `Returns a list of four coordinates.` height(self) `Returns the height of the bbox.` lowerright(self) `Returns the second corner of the bbox. Usually the lower right` midleft(self) `Returns the midpoint of the left edge as a Point object.` midright(self) `Returns the midpoint of the right edge as a Point object.` offset(self, pos) `Returns the vector between the upper-left corner of self and pos. Args: pos: Point object or coordinate tuple. Returns: Point` pos(self, offset) `Returns the position at the given offset from the upper-left` setbottom(self, val) setleft(self, val) `# top, bottom, left, and right can be accessed as attributes` setright(self, val) settop(self, val) union(self, other) `Returns a new bbox that covers self and other. Assumes that the positive y direction is UP.` upperleft(self) `Returns the first corner of the bbox. Usually the upper left` width(self) `Returns the width of the bbox.` Data descriptors defined here: bottom left right top Methods inherited from __builtin__.list: __add__(...) `x.__add__(y) <==> x+y` __contains__(...) `x.__contains__(y) <==> y in x` __delitem__(...) `x.__delitem__(y) <==> del x[y]` __delslice__(...) `x.__delslice__(i, j) <==> del x[i:j] Use of negative indices is not supported.` __eq__(...) `x.__eq__(y) <==> x==y` __ge__(...) `x.__ge__(y) <==> x>=y` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __gt__(...) `x.__gt__(y) <==> x>y` __iadd__(...) `x.__iadd__(y) <==> x+=y` __imul__(...) `x.__imul__(y) <==> x*=y` __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` __iter__(...) `x.__iter__() <==> iter(x)` __le__(...) `x.__le__(y) <==> x<=y` __len__(...) `x.__len__() <==> len(x)` __lt__(...) `x.__lt__(y) <==> x<y` __mul__(...) `x.__mul__(n) <==> x*n` __ne__(...) `x.__ne__(y) <==> x!=y` __repr__(...) `x.__repr__() <==> repr(x)` __reversed__(...) `L.__reversed__() -- return a reverse iterator over the list` __rmul__(...) `x.__rmul__(n) <==> n*x` __setitem__(...) `x.__setitem__(i, y) <==> x[i]=y` __setslice__(...) `x.__setslice__(i, j, y) <==> x[i:j]=y Use of negative indices is not supported.` __sizeof__(...) `L.__sizeof__() -- size of L in memory, in bytes` append(...) `L.append(object) -- append object to end` count(...) `L.count(value) -> integer -- return number of occurrences of value` extend(...) `L.extend(iterable) -- extend list by appending elements from the iterable` index(...) `L.index(value, [start, [stop]]) -> integer -- return first index of value. Raises ValueError if the value is not present.` insert(...) `L.insert(index, object) -- insert object before index` pop(...) `L.pop([index]) -> item -- remove and return item at index (default last). Raises IndexError if list is empty or index is out of range.` remove(...) `L.remove(value) -- remove first occurrence of value. Raises ValueError if the value is not present.` reverse(...) `L.reverse() -- reverse *IN PLACE*` sort(...) `L.sort(cmp=None, key=None, reverse=False) -- stable sort *IN PLACE*; cmp(x, y) -> -1, 0, 1` Data and other attributes inherited from __builtin__.list: __hash__ = None __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T`
class Callable(__builtin__.object)
`` | `Wrap a function and its arguments in a callable object. Callables can can be passed as a callback parameter and invoked later. This code is adapted from the Python Cookbook 9.1, page 302, with one change: if call is invoked with args and kwds, they are added to the args and kwds stored in the Callable.`
| Methods defined here: __call__(self, *args, **kwds) __init__(self, func, *args, **kwds) __str__(self) Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class CanvasTransform(Transform)
`` | `Transform for Cartesian coordinates. Under a CanvasTransform, the origin is in the middle of the canvas, the positive y-axis is up, and the coordinate [1, 1] maps to the point specified by scale.`
| Method resolution order: CanvasTransform Transform __builtin__.object Methods defined here: __init__(self, ca, scale=[1, 1]) invert(self, p) trans(self, p) Methods inherited from Transform: invert_list(self, points) `Applies the inverse transform to the list of points.` trans_list(self, points, func=None) `Applies (func) to a list of points. If (func) is none, applies self.trans.` Data descriptors inherited from Transform: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Gui(Tkinter.Tk)
`` | `Provides wrappers for many of the methods in the Tk class. Keeps track of the current frame so that you can create new widgets without naming the parent frame explicitly.`
| Method resolution order: Gui Tkinter.Tk Tkinter.Misc Tkinter.Wm Methods defined here: __init__(self, debug=False) `Initializes the gui. Turning on debugging changes the behavior of Gui.fr so that the nested frame structure is apparent. Attributes: debug: is a boolean that makes Frames visible if True. frame: is the current Frame. frames: is the stack of pending Frames.` bu(self, text='', command=None, **options) `Makes a button` ca(self, width=100, height=100, **options) `Makes a canvas widget.` cb(self, **options) `Makes a checkbutton.` col(self, weights=[], **options) `Makes a frame that lays out widgets in a single column.` colweight(self, i, weight) `Assigns (weight) to column (i).` colweights(self, weights) `Attaches weights to the columns of the current grid. Args: weights: list of values, assigned to columns starting with 0. These weights control how the columns in the grid expand when the grid expands. The default weight is 0, which means that the column doesn't expand. If only one column has a value, it gets all the extra space.` en(self, **options) `Makes an entry widget.` endcol = endfr(self) endfr(self) `Ends the current frame (and returns the new current frame).` endgr = endfr(self) endrow = endfr(self) fr(self, *args, **options) `Makes and returns a frame. The new frame becomes the current frame. By default, frames use the pack geometry manager, unless self.gridding=True.` gr(self, cols, cweights=[], rweights=[], **options) `Makes a frame and switches to grid mode. (cols) is the number of columns in the grid. (cweights) and (rweights) control how the widgets expand if the frame expands (see colweights and rowweights below). By default, the first 8 rows and columns are set to expand. (options) is a dictionary that is underridden and passed along.` grid(self, widget, i=None, j=None, **options) `Packs the given widget in the current grid. By default, the widget is packed in the next available space, but parameters i and j can specify the row and column explicitly.` la(self, text='', **options) `Makes a label widget.` lb(self, **options) `Makes a listbox.` mb(self, **options) `Makes a menubutton` mi(self, mb, text='', **options) `Makes a menu item` popfr = endfr(self) pushfr(self, frame) `Pushes a frame onto the frame stack.` rb(self, **options) `Makes a radiobutton` row(self, weights=[], **options) `Makes a frame that lays out widgets in a single row.` rowweight(self, i, weight) `Assigns (weight) to row (i).` rowweights(self, weights) `Attaches weights to the rows of the current grid. Args: weights: is a list of values, which are assigned to rows starting with 0. These weights control how the rows in the grid expand when the grid expands. The default weight is 0, which means that the row doesn't expand. If only one row has a value, it gets all the extra space.` sb(self, **options) `Makes a text scrollbar` sc(self, **options) `Makes a scrollable canvas. The options provided apply to the frame only; if you want to configure the other widgets, you have to do it after invoking st.` st(self, **options) `Makes a scrollable text entry.` te(self, **options) `Makes a text entry` tl(self, **options) `Makes and returns a top level window.` widget(self, constructor, **options) `Makes a widget of the given type. options is split into widget options, pack options and grid options. Args: constructor: function called to build the new widget. options: option dictionary Returns: new widget` Data and other attributes defined here: ScrollableCanvas = <class 'Gui.ScrollableCanvas'> `A grid with a canvas and two scrollbars.` ScrollableText = <class 'Gui.ScrollableText'> `A frame with a text entry and a scrollbar.` Methods inherited from Tkinter.Tk: __getattr__(self, attr) `Delegate attribute access to the interpreter object` destroy(self) `Destroy this and all descendants widgets. This will end the application of this Tcl interpreter.` loadtk(self) readprofile(self, baseName, className) `Internal function. It reads BASENAME.tcl and CLASSNAME.tcl into the Tcl Interpreter and calls execfile on BASENAME.py and CLASSNAME.py if such a file exists in the home directory.` report_callback_exception(self, exc, val, tb) `Internal function. It reports exception on sys.stderr.` Methods inherited from Tkinter.Misc: __contains__(self, key) __getitem__ = cget(self, key) `Return the resource value for a KEY given as string.` __setitem__(self, key, value) __str__(self) `Return the window path name of this widget.` after(self, ms, func=None, *args) `Call function once after given time. MS specifies the time in milliseconds. FUNC gives the function which shall be called. Additional parameters are given as parameters to the function call. Return identifier to cancel scheduling with after_cancel.` after_cancel(self, id) `Cancel scheduling of function identified with ID. Identifier returned by after or after_idle must be given as first parameter.` after_idle(self, func, *args) `Call FUNC once if the Tcl main loop has no event to process. Return an identifier to cancel the scheduling with after_cancel.` bbox = grid_bbox(self, column=None, row=None, col2=None, row2=None) `Return a tuple of integer coordinates for the bounding box of this widget controlled by the geometry manager grid. If COLUMN, ROW is given the bounding box applies from the cell with row and column 0 to the specified cell. If COL2 and ROW2 are given the bounding box starts at that cell. The returned integers specify the offset of the upper left corner in the master widget and the width and height.` bell(self, displayof=0) `Ring a display's bell.` bind(self, sequence=None, func=None, add=None) `Bind to this widget at event SEQUENCE a call to function FUNC. SEQUENCE is a string of concatenated event patterns. An event pattern is of the form <MODIFIER-MODIFIER-TYPE-DETAIL> where MODIFIER is one of Control, Mod2, M2, Shift, Mod3, M3, Lock, Mod4, M4, Button1, B1, Mod5, M5 Button2, B2, Meta, M, Button3, B3, Alt, Button4, B4, Double, Button5, B5 Triple, Mod1, M1. TYPE is one of Activate, Enter, Map, ButtonPress, Button, Expose, Motion, ButtonRelease FocusIn, MouseWheel, Circulate, FocusOut, Property, Colormap, Gravity Reparent, Configure, KeyPress, Key, Unmap, Deactivate, KeyRelease Visibility, Destroy, Leave and DETAIL is the button number for ButtonPress, ButtonRelease and DETAIL is the Keysym for KeyPress and KeyRelease. Examples are <Control-Button-1> for pressing Control and mouse button 1 or <Alt-A> for pressing A and the Alt key (KeyPress can be omitted). An event pattern can also be a virtual event of the form <<AString>> where AString can be arbitrary. This event can be generated by event_generate. If events are concatenated they must appear shortly after each other. FUNC will be called if the event sequence occurs with an instance of Event as argument. If the return value of FUNC is "break" no further bound function is invoked. An additional boolean parameter ADD specifies whether FUNC will be called additionally to the other bound function or whether it will replace the previous function. Bind will return an identifier to allow deletion of the bound function with unbind without memory leak. If FUNC or SEQUENCE is omitted the bound function or list of bound events are returned.` bind_all(self, sequence=None, func=None, add=None) `Bind to all widgets at an event SEQUENCE a call to function FUNC. An additional boolean parameter ADD specifies whether FUNC will be called additionally to the other bound function or whether it will replace the previous function. See bind for the return value.` bind_class(self, className, sequence=None, func=None, add=None) `Bind to widgets with bindtag CLASSNAME at event SEQUENCE a call of function FUNC. An additional boolean parameter ADD specifies whether FUNC will be called additionally to the other bound function or whether it will replace the previous function. See bind for the return value.` bindtags(self, tagList=None) `Set or get the list of bindtags for this widget. With no argument return the list of all bindtags associated with this widget. With a list of strings as argument the bindtags are set to this list. The bindtags determine in which order events are processed (see bind).` cget(self, key) `Return the resource value for a KEY given as string.` clipboard_append(self, string, **kw) `Append STRING to the Tk clipboard. A widget specified at the optional displayof keyword argument specifies the target display. The clipboard can be retrieved with selection_get.` clipboard_clear(self, **kw) `Clear the data in the Tk clipboard. A widget specified for the optional displayof keyword argument specifies the target display.` clipboard_get(self, **kw) `Retrieve data from the clipboard on window's display. The window keyword defaults to the root window of the Tkinter application. The type keyword specifies the form in which the data is to be returned and should be an atom name such as STRING or FILE_NAME. Type defaults to STRING, except on X11, where the default is to try UTF8_STRING and fall back to STRING. This command is equivalent to: selection_get(CLIPBOARD)` colormodel(self, value=None) `Useless. Not implemented in Tk.` columnconfigure = grid_columnconfigure(self, index, cnf={}, **kw) `Configure column INDEX of a grid. Valid resources are minsize (minimum size of the column), weight (how much does additional space propagate to this column) and pad (how much space to let additionally).` config = configure(self, cnf=None, **kw) `Configure resources of a widget. The values for resources are specified as keyword arguments. To get an overview about the allowed keyword arguments call the method keys.` configure(self, cnf=None, **kw) `Configure resources of a widget. The values for resources are specified as keyword arguments. To get an overview about the allowed keyword arguments call the method keys.` deletecommand(self, name) `Internal function. Delete the Tcl command provided in NAME.` event_add(self, virtual, *sequences) `Bind a virtual event VIRTUAL (of the form <<Name>>) to an event SEQUENCE such that the virtual event is triggered whenever SEQUENCE occurs.` event_delete(self, virtual, *sequences) `Unbind a virtual event VIRTUAL from SEQUENCE.` event_generate(self, sequence, **kw) `Generate an event SEQUENCE. Additional keyword arguments specify parameter of the event (e.g. x, y, rootx, rooty).` event_info(self, virtual=None) `Return a list of all virtual events or the information about the SEQUENCE bound to the virtual event VIRTUAL.` focus = focus_set(self) `Direct input focus to this widget. If the application currently does not have the focus this widget will get the focus if the application gets the focus through the window manager.` focus_displayof(self) `Return the widget which has currently the focus on the display where this widget is located. Return None if the application does not have the focus.` focus_force(self) `Direct input focus to this widget even if the application does not have the focus. Use with caution!` focus_get(self) `Return the widget which has currently the focus in the application. Use focus_displayof to allow working with several displays. Return None if application does not have the focus.` focus_lastfor(self) `Return the widget which would have the focus if top level for this widget gets the focus from the window manager.` focus_set(self) `Direct input focus to this widget. If the application currently does not have the focus this widget will get the focus if the application gets the focus through the window manager.` getboolean(self, s) `Return a boolean value for Tcl boolean values true and false given as parameter.` getvar(self, name='PY_VAR') `Return value of Tcl variable NAME.` grab_current(self) `Return widget which has currently the grab in this application or None.` grab_release(self) `Release grab for this widget if currently set.` grab_set(self) `Set grab for this widget. A grab directs all events to this and descendant widgets in the application.` grab_set_global(self) `Set global grab for this widget. A global grab directs all events to this and descendant widgets on the display. Use with caution - other applications do not get events anymore.` grab_status(self) `Return None, "local" or "global" if this widget has no, a local or a global grab.` grid_bbox(self, column=None, row=None, col2=None, row2=None) `Return a tuple of integer coordinates for the bounding box of this widget controlled by the geometry manager grid. If COLUMN, ROW is given the bounding box applies from the cell with row and column 0 to the specified cell. If COL2 and ROW2 are given the bounding box starts at that cell. The returned integers specify the offset of the upper left corner in the master widget and the width and height.` grid_columnconfigure(self, index, cnf={}, **kw) `Configure column INDEX of a grid. Valid resources are minsize (minimum size of the column), weight (how much does additional space propagate to this column) and pad (how much space to let additionally).` grid_location(self, x, y) `Return a tuple of column and row which identify the cell at which the pixel at position X and Y inside the master widget is located.` grid_propagate(self, flag=['_noarg_']) `Set or get the status for propagation of geometry information. A boolean argument specifies whether the geometry information of the slaves will determine the size of this widget. If no argument is given, the current setting will be returned.` grid_rowconfigure(self, index, cnf={}, **kw) `Configure row INDEX of a grid. Valid resources are minsize (minimum size of the row), weight (how much does additional space propagate to this row) and pad (how much space to let additionally).` grid_size(self) `Return a tuple of the number of column and rows in the grid.` grid_slaves(self, row=None, column=None) `Return a list of all slaves of this widget in its packing order.` image_names(self) `Return a list of all existing image names.` image_types(self) `Return a list of all available image types (e.g. phote bitmap).` keys(self) `Return a list of all resource names of this widget.` lift = tkraise(self, aboveThis=None) `Raise this widget in the stacking order.` lower(self, belowThis=None) `Lower this widget in the stacking order.` mainloop(self, n=0) `Call the mainloop of Tk.` nametowidget(self, name) `Return the Tkinter instance of a widget identified by its Tcl name NAME.` option_add(self, pattern, value, priority=None) `Set a VALUE (second parameter) for an option PATTERN (first parameter). An optional third parameter gives the numeric priority (defaults to 80).` option_clear(self) `Clear the option database. It will be reloaded if option_add is called.` option_get(self, name, className) `Return the value for an option NAME for this widget with CLASSNAME. Values with higher priority override lower values.` option_readfile(self, fileName, priority=None) `Read file FILENAME into the option database. An optional second parameter gives the numeric priority.` pack_propagate(self, flag=['_noarg_']) `Set or get the status for propagation of geometry information. A boolean argument specifies whether the geometry information of the slaves will determine the size of this widget. If no argument is given the current setting will be returned.` pack_slaves(self) `Return a list of all slaves of this widget in its packing order.` place_slaves(self) `Return a list of all slaves of this widget in its packing order.` propagate = pack_propagate(self, flag=['_noarg_']) `Set or get the status for propagation of geometry information. A boolean argument specifies whether the geometry information of the slaves will determine the size of this widget. If no argument is given the current setting will be returned.` quit(self) `Quit the Tcl interpreter. All widgets will be destroyed.` register = _register(self, func, subst=None, needcleanup=1) `Return a newly created Tcl function. If this function is called, the Python function FUNC will be executed. An optional function SUBST can be given which will be executed before FUNC.` rowconfigure = grid_rowconfigure(self, index, cnf={}, **kw) `Configure row INDEX of a grid. Valid resources are minsize (minimum size of the row), weight (how much does additional space propagate to this row) and pad (how much space to let additionally).` selection_clear(self, **kw) `Clear the current X selection.` selection_get(self, **kw) `Return the contents of the current X selection. A keyword parameter selection specifies the name of the selection and defaults to PRIMARY. A keyword parameter displayof specifies a widget on the display to use. A keyword parameter type specifies the form of data to be fetched, defaulting to STRING except on X11, where UTF8_STRING is tried before STRING.` selection_handle(self, command, **kw) `Specify a function COMMAND to call if the X selection owned by this widget is queried by another application. This function must return the contents of the selection. The function will be called with the arguments OFFSET and LENGTH which allows the chunking of very long selections. The following keyword parameters can be provided: selection - name of the selection (default PRIMARY), type - type of the selection (e.g. STRING, FILE_NAME).` selection_own(self, **kw) `Become owner of X selection. A keyword parameter selection specifies the name of the selection (default PRIMARY).` selection_own_get(self, **kw) `Return owner of X selection. The following keyword parameter can be provided: selection - name of the selection (default PRIMARY), type - type of the selection (e.g. STRING, FILE_NAME).` send(self, interp, cmd, *args) `Send Tcl command CMD to different interpreter INTERP to be executed.` setvar(self, name='PY_VAR', value='1') `Set Tcl variable NAME to VALUE.` size = grid_size(self) `Return a tuple of the number of column and rows in the grid.` slaves = pack_slaves(self) `Return a list of all slaves of this widget in its packing order.` tk_bisque(self) `Change the color scheme to light brown as used in Tk 3.6 and before.` tk_focusFollowsMouse(self) `The widget under mouse will get automatically focus. Can not be disabled easily.` tk_focusNext(self) `Return the next widget in the focus order which follows widget which has currently the focus. The focus order first goes to the next child, then to the children of the child recursively and then to the next sibling which is higher in the stacking order. A widget is omitted if it has the takefocus resource set to 0.` tk_focusPrev(self) `Return previous widget in the focus order. See tk_focusNext for details.` tk_menuBar(self, *args) `Do not use. Needed in Tk 3.6 and earlier.` tk_setPalette(self, *args, **kw) `Set a new color scheme for all widget elements. A single color as argument will cause that all colors of Tk widget elements are derived from this. Alternatively several keyword parameters and its associated colors can be given. The following keywords are valid: activeBackground, foreground, selectColor, activeForeground, highlightBackground, selectBackground, background, highlightColor, selectForeground, disabledForeground, insertBackground, troughColor.` tk_strictMotif(self, boolean=None) `Set Tcl internal variable, whether the look and feel should adhere to Motif. A parameter of 1 means adhere to Motif (e.g. no color change if mouse passes over slider). Returns the set value.` tkraise(self, aboveThis=None) `Raise this widget in the stacking order.` unbind(self, sequence, funcid=None) `Unbind for this widget for event SEQUENCE the function identified with FUNCID.` unbind_all(self, sequence) `Unbind for all widgets for event SEQUENCE all functions.` unbind_class(self, className, sequence) `Unbind for a all widgets with bindtag CLASSNAME for event SEQUENCE all functions.` update(self) `Enter event loop until all pending events have been processed by Tcl.` update_idletasks(self) `Enter event loop until all idle callbacks have been called. This will update the display of windows but not process events caused by the user.` wait_variable(self, name='PY_VAR') `Wait until the variable is modified. A parameter of type IntVar, StringVar, DoubleVar or BooleanVar must be given.` wait_visibility(self, window=None) `Wait until the visibility of a WIDGET changes (e.g. it appears). If no parameter is given self is used.` wait_window(self, window=None) `Wait until a WIDGET is destroyed. If no parameter is given self is used.` waitvar = wait_variable(self, name='PY_VAR') `Wait until the variable is modified. A parameter of type IntVar, StringVar, DoubleVar or BooleanVar must be given.` winfo_atom(self, name, displayof=0) `Return integer which represents atom NAME.` winfo_atomname(self, id, displayof=0) `Return name of atom with identifier ID.` winfo_cells(self) `Return number of cells in the colormap for this widget.` winfo_children(self) `Return a list of all widgets which are children of this widget.` winfo_class(self) `Return window class name of this widget.` winfo_colormapfull(self) `Return true if at the last color request the colormap was full.` winfo_containing(self, rootX, rootY, displayof=0) `Return the widget which is at the root coordinates ROOTX, ROOTY.` winfo_depth(self) `Return the number of bits per pixel.` winfo_exists(self) `Return true if this widget exists.` winfo_fpixels(self, number) `Return the number of pixels for the given distance NUMBER (e.g. "3c") as float.` winfo_geometry(self) `Return geometry string for this widget in the form "widthxheight+X+Y".` winfo_height(self) `Return height of this widget.` winfo_id(self) `Return identifier ID for this widget.` winfo_interps(self, displayof=0) `Return the name of all Tcl interpreters for this display.` winfo_ismapped(self) `Return true if this widget is mapped.` winfo_manager(self) `Return the window mananger name for this widget.` winfo_name(self) `Return the name of this widget.` winfo_parent(self) `Return the name of the parent of this widget.` winfo_pathname(self, id, displayof=0) `Return the pathname of the widget given by ID.` winfo_pixels(self, number) `Rounded integer value of winfo_fpixels.` winfo_pointerx(self) `Return the x coordinate of the pointer on the root window.` winfo_pointerxy(self) `Return a tuple of x and y coordinates of the pointer on the root window.` winfo_pointery(self) `Return the y coordinate of the pointer on the root window.` winfo_reqheight(self) `Return requested height of this widget.` winfo_reqwidth(self) `Return requested width of this widget.` winfo_rgb(self, color) `Return tuple of decimal values for red, green, blue for COLOR in this widget.` winfo_rootx(self) `Return x coordinate of upper left corner of this widget on the root window.` winfo_rooty(self) `Return y coordinate of upper left corner of this widget on the root window.` winfo_screen(self) `Return the screen name of this widget.` winfo_screencells(self) `Return the number of the cells in the colormap of the screen of this widget.` winfo_screendepth(self) `Return the number of bits per pixel of the root window of the screen of this widget.` winfo_screenheight(self) `Return the number of pixels of the height of the screen of this widget in pixel.` winfo_screenmmheight(self) `Return the number of pixels of the height of the screen of this widget in mm.` winfo_screenmmwidth(self) `Return the number of pixels of the width of the screen of this widget in mm.` winfo_screenvisual(self) `Return one of the strings directcolor, grayscale, pseudocolor, staticcolor, staticgray, or truecolor for the default colormodel of this screen.` winfo_screenwidth(self) `Return the number of pixels of the width of the screen of this widget in pixel.` winfo_server(self) `Return information of the X-Server of the screen of this widget in the form "XmajorRminor vendor vendorVersion".` winfo_toplevel(self) `Return the toplevel widget of this widget.` winfo_viewable(self) `Return true if the widget and all its higher ancestors are mapped.` winfo_visual(self) `Return one of the strings directcolor, grayscale, pseudocolor, staticcolor, staticgray, or truecolor for the colormodel of this widget.` winfo_visualid(self) `Return the X identifier for the visual for this widget.` winfo_visualsavailable(self, includeids=0) `Return a list of all visuals available for the screen of this widget. Each item in the list consists of a visual name (see winfo_visual), a depth and if INCLUDEIDS=1 is given also the X identifier.` winfo_vrootheight(self) `Return the height of the virtual root window associated with this widget in pixels. If there is no virtual root window return the height of the screen.` winfo_vrootwidth(self) `Return the width of the virtual root window associated with this widget in pixel. If there is no virtual root window return the width of the screen.` winfo_vrootx(self) `Return the x offset of the virtual root relative to the root window of the screen of this widget.` winfo_vrooty(self) `Return the y offset of the virtual root relative to the root window of the screen of this widget.` winfo_width(self) `Return the width of this widget.` winfo_x(self) `Return the x coordinate of the upper left corner of this widget in the parent.` winfo_y(self) `Return the y coordinate of the upper left corner of this widget in the parent.` Data and other attributes inherited from Tkinter.Misc: getdouble = <type 'float'> `float(x) -> floating point number Convert a string or number to a floating point number, if possible.` getint = <type 'int'> `int(x=0) -> int or long int(x, base=10) -> int or long Convert a number or string to an integer, or return 0 if no arguments are given. If x is floating point, the conversion truncates towards zero. If x is outside the integer range, the function returns a long instead. If x is not a number or if base is given, then x must be a string or Unicode object representing an integer literal in the given base. The literal can be preceded by '+' or '-' and be surrounded by whitespace. The base defaults to 10. Valid bases are 0 and 2-36. Base 0 means to interpret the base from the string as an integer literal. >>> int('0b100', base=0) 4` Methods inherited from Tkinter.Wm: aspect = wm_aspect(self, minNumer=None, minDenom=None, maxNumer=None, maxDenom=None) `Instruct the window manager to set the aspect ratio (width/height) of this widget to be between MINNUMER/MINDENOM and MAXNUMER/MAXDENOM. Return a tuple of the actual values if no argument is given.` attributes = wm_attributes(self, *args) `This subcommand returns or sets platform specific attributes The first form returns a list of the platform specific flags and their values. The second form returns the value for the specific option. The third form sets one or more of the values. The values are as follows: On Windows, -disabled gets or sets whether the window is in a disabled state. -toolwindow gets or sets the style of the window to toolwindow (as defined in the MSDN). -topmost gets or sets whether this is a topmost window (displays above all other windows). On Macintosh, XXXXX On Unix, there are currently no special attribute values.` client = wm_client(self, name=None) `Store NAME in WM_CLIENT_MACHINE property of this widget. Return current value.` colormapwindows = wm_colormapwindows(self, *wlist) `Store list of window names (WLIST) into WM_COLORMAPWINDOWS property of this widget. This list contains windows whose colormaps differ from their parents. Return current list of widgets if WLIST is empty.` command = wm_command(self, value=None) `Store VALUE in WM_COMMAND property. It is the command which shall be used to invoke the application. Return current command if VALUE is None.` deiconify = wm_deiconify(self) `Deiconify this widget. If it was never mapped it will not be mapped. On Windows it will raise this widget and give it the focus.` focusmodel = wm_focusmodel(self, model=None) `Set focus model to MODEL. "active" means that this widget will claim the focus itself, "passive" means that the window manager shall give the focus. Return current focus model if MODEL is None.` frame = wm_frame(self) `Return identifier for decorative frame of this widget if present.` geometry = wm_geometry(self, newGeometry=None) `Set geometry to NEWGEOMETRY of the form =widthxheight+x+y. Return current value if None is given.` group = wm_group(self, pathName=None) `Set the group leader widgets for related widgets to PATHNAME. Return the group leader of this widget if None is given.` iconbitmap = wm_iconbitmap(self, bitmap=None, default=None) `Set bitmap for the iconified widget to BITMAP. Return the bitmap if None is given. Under Windows, the DEFAULT parameter can be used to set the icon for the widget and any descendents that don't have an icon set explicitly. DEFAULT can be the relative path to a .ico file (example: root.iconbitmap(default='myicon.ico') ). See Tk documentation for more information.` iconify = wm_iconify(self) `Display widget as icon.` iconmask = wm_iconmask(self, bitmap=None) `Set mask for the icon bitmap of this widget. Return the mask if None is given.` iconname = wm_iconname(self, newName=None) `Set the name of the icon for this widget. Return the name if None is given.` iconposition = wm_iconposition(self, x=None, y=None) `Set the position of the icon of this widget to X and Y. Return a tuple of the current values of X and X if None is given.` iconwindow = wm_iconwindow(self, pathName=None) `Set widget PATHNAME to be displayed instead of icon. Return the current value if None is given.` maxsize = wm_maxsize(self, width=None, height=None) `Set max WIDTH and HEIGHT for this widget. If the window is gridded the values are given in grid units. Return the current values if None is given.` minsize = wm_minsize(self, width=None, height=None) `Set min WIDTH and HEIGHT for this widget. If the window is gridded the values are given in grid units. Return the current values if None is given.` overrideredirect = wm_overrideredirect(self, boolean=None) `Instruct the window manager to ignore this widget if BOOLEAN is given with 1. Return the current value if None is given.` positionfrom = wm_positionfrom(self, who=None) `Instruct the window manager that the position of this widget shall be defined by the user if WHO is "user", and by its own policy if WHO is "program".` protocol = wm_protocol(self, name=None, func=None) `Bind function FUNC to command NAME for this widget. Return the function bound to NAME if None is given. NAME could be e.g. "WM_SAVE_YOURSELF" or "WM_DELETE_WINDOW".` resizable = wm_resizable(self, width=None, height=None) `Instruct the window manager whether this width can be resized in WIDTH or HEIGHT. Both values are boolean values.` sizefrom = wm_sizefrom(self, who=None) `Instruct the window manager that the size of this widget shall be defined by the user if WHO is "user", and by its own policy if WHO is "program".` state = wm_state(self, newstate=None) `Query or set the state of this widget as one of normal, icon, iconic (see wm_iconwindow), withdrawn, or zoomed (Windows only).` title = wm_title(self, string=None) `Set the title of this widget.` transient = wm_transient(self, master=None) `Instruct the window manager that this widget is transient with regard to widget MASTER.` withdraw = wm_withdraw(self) `Withdraw this widget from the screen such that it is unmapped and forgotten by the window manager. Re-draw it with wm_deiconify.` wm_aspect(self, minNumer=None, minDenom=None, maxNumer=None, maxDenom=None) `Instruct the window manager to set the aspect ratio (width/height) of this widget to be between MINNUMER/MINDENOM and MAXNUMER/MAXDENOM. Return a tuple of the actual values if no argument is given.` wm_attributes(self, *args) `This subcommand returns or sets platform specific attributes The first form returns a list of the platform specific flags and their values. The second form returns the value for the specific option. The third form sets one or more of the values. The values are as follows: On Windows, -disabled gets or sets whether the window is in a disabled state. -toolwindow gets or sets the style of the window to toolwindow (as defined in the MSDN). -topmost gets or sets whether this is a topmost window (displays above all other windows). On Macintosh, XXXXX On Unix, there are currently no special attribute values.` wm_client(self, name=None) `Store NAME in WM_CLIENT_MACHINE property of this widget. Return current value.` wm_colormapwindows(self, *wlist) `Store list of window names (WLIST) into WM_COLORMAPWINDOWS property of this widget. This list contains windows whose colormaps differ from their parents. Return current list of widgets if WLIST is empty.` wm_command(self, value=None) `Store VALUE in WM_COMMAND property. It is the command which shall be used to invoke the application. Return current command if VALUE is None.` wm_deiconify(self) `Deiconify this widget. If it was never mapped it will not be mapped. On Windows it will raise this widget and give it the focus.` wm_focusmodel(self, model=None) `Set focus model to MODEL. "active" means that this widget will claim the focus itself, "passive" means that the window manager shall give the focus. Return current focus model if MODEL is None.` wm_frame(self) `Return identifier for decorative frame of this widget if present.` wm_geometry(self, newGeometry=None) `Set geometry to NEWGEOMETRY of the form =widthxheight+x+y. Return current value if None is given.` wm_grid(self, baseWidth=None, baseHeight=None, widthInc=None, heightInc=None) `Instruct the window manager that this widget shall only be resized on grid boundaries. WIDTHINC and HEIGHTINC are the width and height of a grid unit in pixels. BASEWIDTH and BASEHEIGHT are the number of grid units requested in Tk_GeometryRequest.` wm_group(self, pathName=None) `Set the group leader widgets for related widgets to PATHNAME. Return the group leader of this widget if None is given.` wm_iconbitmap(self, bitmap=None, default=None) `Set bitmap for the iconified widget to BITMAP. Return the bitmap if None is given. Under Windows, the DEFAULT parameter can be used to set the icon for the widget and any descendents that don't have an icon set explicitly. DEFAULT can be the relative path to a .ico file (example: root.iconbitmap(default='myicon.ico') ). See Tk documentation for more information.` wm_iconify(self) `Display widget as icon.` wm_iconmask(self, bitmap=None) `Set mask for the icon bitmap of this widget. Return the mask if None is given.` wm_iconname(self, newName=None) `Set the name of the icon for this widget. Return the name if None is given.` wm_iconposition(self, x=None, y=None) `Set the position of the icon of this widget to X and Y. Return a tuple of the current values of X and X if None is given.` wm_iconwindow(self, pathName=None) `Set widget PATHNAME to be displayed instead of icon. Return the current value if None is given.` wm_maxsize(self, width=None, height=None) `Set max WIDTH and HEIGHT for this widget. If the window is gridded the values are given in grid units. Return the current values if None is given.` wm_minsize(self, width=None, height=None) `Set min WIDTH and HEIGHT for this widget. If the window is gridded the values are given in grid units. Return the current values if None is given.` wm_overrideredirect(self, boolean=None) `Instruct the window manager to ignore this widget if BOOLEAN is given with 1. Return the current value if None is given.` wm_positionfrom(self, who=None) `Instruct the window manager that the position of this widget shall be defined by the user if WHO is "user", and by its own policy if WHO is "program".` wm_protocol(self, name=None, func=None) `Bind function FUNC to command NAME for this widget. Return the function bound to NAME if None is given. NAME could be e.g. "WM_SAVE_YOURSELF" or "WM_DELETE_WINDOW".` wm_resizable(self, width=None, height=None) `Instruct the window manager whether this width can be resized in WIDTH or HEIGHT. Both values are boolean values.` wm_sizefrom(self, who=None) `Instruct the window manager that the size of this widget shall be defined by the user if WHO is "user", and by its own policy if WHO is "program".` wm_state(self, newstate=None) `Query or set the state of this widget as one of normal, icon, iconic (see wm_iconwindow), withdrawn, or zoomed (Windows only).` wm_title(self, string=None) `Set the title of this widget.` wm_transient(self, master=None) `Instruct the window manager that this widget is transient with regard to widget MASTER.` wm_withdraw(self) `Withdraw this widget from the screen such that it is unmapped and forgotten by the window manager. Re-draw it with wm_deiconify.`
class GuiCanvas(Tkinter.Canvas)
`` | `A wrapper for the Canvas provided by Tkinter. The primary difference is that it supports coordinate transformations, the most common of which is the CanvasTranform, which makes canvas coordinates Cartesian (origin in the middle, positive y axis going up). It also provides methods like circle that provide a nice interface to the underlying canvas methods. The item-creating methods all return Item objects (as opposed to Tkinter tags) so you can perform subsequent operations by invoking methods on the Items, rather than the Canvas.`
| Method resolution order: GuiCanvas Tkinter.Canvas Tkinter.Widget Tkinter.BaseWidget Tkinter.Misc Tkinter.Pack Tkinter.Place Tkinter.Grid Tkinter.XView Tkinter.YView Methods defined here: __init__(self, w, scale=[1, 1], transforms=None, **options) add_transform(self, transform, index=None) `Add a transform. Args: transform: Transform object index: where in the list to insert it; appending is the default.` arc(self, coords, start=0, extent=90, fill='', **options) `Makes an arc item. with bounding box (coords), sweeping out angle (extent) starting at (start) both in degrees.` bbox(self, item) `Compute the bounding box of the given item. Transforms from pixel coordinates to canvas coordinates. Args: item: tag of a canvas item Returns: Bbox object in canvas coordinates.` bitmap(self, coord, bitmap, **options) `Makes a bitmap item. with the given bitmap at the given position. The default anchor is center.` canvas_coords(self, coords) `Convert a position from pixel coordinates to Canvas coordinates. Args: coords: Point object or list of coordinates.` canvas_itemcoords(self, item, coords=None) `Gets and sets item coordinates, with translation. Args: item: tag of a canvas item coords: Point object or list of coordinates` circle(self, coord, r, fill='', **options) `Makes a circle. with center at (x, y) and radius (r)` clear(self) `Deletes all items on the canvas.` clear_transforms(self) `Removes all existing transforms.` dump(self, filename='canvas.eps') `Create a PostScipt file and dumps the contents of the canvas.` get_height(self) `Gets the nominal height of this canvas.` get_width(self) `Gets the nominal width of this canvas.` image(self, coord, image, **options) `Makes an image item. with the given image at the given position. The default anchor is center.` invert(self, coords) `Applies the inverse of each transforms, in reverse order.` line(self, coords, fill='black', **options) `Makes a polyline. with vertices at each point in (coords) and pen color (fill).` move(self, item, dx, dy, transform=False) `Moves an item on the canvas. Args: item: string tag of a canvas item dx: distance to move on the x axis dy: distance to move on the y axis transform: boolean, whether to transform dx, dy` oval(self, coords, fill='', **options) `Makes an oval. with bounding box (coords) and fill color (fill)` polygon(self, coords, fill='', **options) `Makes a closed polygon. with vertices at each point in (coords) and fill color (fill).` rectangle(self, coords, fill='', **options) `Makes an oval. with bounding box (coords) and fill color (fill)` scroll_config(self, tag='all') `Configure the canvas so the scroll region covers the given tag.` text(self, coord, text='', fill='black', **options) `Makes a text item. with the given text and fill color. The default anchor is center.` trans(self, coords) `Applies each of the transforms for this canvas, in order.` translate_event(self, event) `Translates event strings into a canonical form. Args: event: Tkinter event string Returns: Tkinter event string` window(self, coord, widget, **options) `Embeds a window (widget) in the canvas at the given coord.` Data descriptors defined here: height `Gets the nominal height of this canvas.` width `Gets the nominal width of this canvas.` Methods inherited from Tkinter.Canvas: addtag(self, *args) `Internal function.` addtag_above(self, newtag, tagOrId) `Add tag NEWTAG to all items above TAGORID.` addtag_all(self, newtag) `Add tag NEWTAG to all items.` addtag_below(self, newtag, tagOrId) `Add tag NEWTAG to all items below TAGORID.` addtag_closest(self, newtag, x, y, halo=None, start=None) `Add tag NEWTAG to item which is closest to pixel at X, Y. If several match take the top-most. All items closer than HALO are considered overlapping (all are closests). If START is specified the next below this tag is taken.` addtag_enclosed(self, newtag, x1, y1, x2, y2) `Add tag NEWTAG to all items in the rectangle defined by X1,Y1,X2,Y2.` addtag_overlapping(self, newtag, x1, y1, x2, y2) `Add tag NEWTAG to all items which overlap the rectangle defined by X1,Y1,X2,Y2.` addtag_withtag(self, newtag, tagOrId) `Add tag NEWTAG to all items with TAGORID.` canvasx(self, screenx, gridspacing=None) `Return the canvas x coordinate of pixel position SCREENX rounded to nearest multiple of GRIDSPACING units.` canvasy(self, screeny, gridspacing=None) `Return the canvas y coordinate of pixel position SCREENY rounded to nearest multiple of GRIDSPACING units.` coords(self, *args) `Return a list of coordinates for the item given in ARGS.` create_arc(self, *args, **kw) `Create arc shaped region with coordinates x1,y1,x2,y2.` create_bitmap(self, *args, **kw) `Create bitmap with coordinates x1,y1.` create_image(self, *args, **kw) `Create image item with coordinates x1,y1.` create_line(self, *args, **kw) `Create line with coordinates x1,y1,...,xn,yn.` create_oval(self, *args, **kw) `Create oval with coordinates x1,y1,x2,y2.` create_polygon(self, *args, **kw) `Create polygon with coordinates x1,y1,...,xn,yn.` create_rectangle(self, *args, **kw) `Create rectangle with coordinates x1,y1,x2,y2.` create_text(self, *args, **kw) `Create text with coordinates x1,y1.` create_window(self, *args, **kw) `Create window with coordinates x1,y1,x2,y2.` dchars(self, *args) `Delete characters of text items identified by tag or id in ARGS (possibly several times) from FIRST to LAST character (including).` delete(self, *args) `Delete items identified by all tag or ids contained in ARGS.` dtag(self, *args) `Delete tag or id given as last arguments in ARGS from items identified by first argument in ARGS.` find(self, *args) `Internal function.` find_above(self, tagOrId) `Return items above TAGORID.` find_all(self) `Return all items.` find_below(self, tagOrId) `Return all items below TAGORID.` find_closest(self, x, y, halo=None, start=None) `Return item which is closest to pixel at X, Y. If several match take the top-most. All items closer than HALO are considered overlapping (all are closests). If START is specified the next below this tag is taken.` find_enclosed(self, x1, y1, x2, y2) `Return all items in rectangle defined by X1,Y1,X2,Y2.` find_overlapping(self, x1, y1, x2, y2) `Return all items which overlap the rectangle defined by X1,Y1,X2,Y2.` find_withtag(self, tagOrId) `Return all items with TAGORID.` focus(self, *args) `Set focus to the first item specified in ARGS.` gettags(self, *args) `Return tags associated with the first item specified in ARGS.` icursor(self, *args) `Set cursor at position POS in the item identified by TAGORID. In ARGS TAGORID must be first.` index(self, *args) `Return position of cursor as integer in item specified in ARGS.` insert(self, *args) `Insert TEXT in item TAGORID at position POS. ARGS must be TAGORID POS TEXT.` itemcget(self, tagOrId, option) `Return the resource value for an OPTION for item TAGORID.` itemconfig = itemconfigure(self, tagOrId, cnf=None, **kw) `Configure resources of an item TAGORID. The values for resources are specified as keyword arguments. To get an overview about the allowed keyword arguments call the method without arguments.` itemconfigure(self, tagOrId, cnf=None, **kw) `Configure resources of an item TAGORID. The values for resources are specified as keyword arguments. To get an overview about the allowed keyword arguments call the method without arguments.` lift = tag_raise(self, *args) `Raise an item TAGORID given in ARGS (optional above another item).` lower = tag_lower(self, *args) `Lower an item TAGORID given in ARGS (optional below another item).` postscript(self, cnf={}, **kw) `Print the contents of the canvas to a postscript file. Valid options: colormap, colormode, file, fontmap, height, pageanchor, pageheight, pagewidth, pagex, pagey, rotate, witdh, x, y.` scale(self, *args) `Scale item TAGORID with XORIGIN, YORIGIN, XSCALE, YSCALE.` scan_dragto(self, x, y, gain=10) `Adjust the view of the canvas to GAIN times the difference between X and Y and the coordinates given in scan_mark.` scan_mark(self, x, y) `Remember the current X, Y coordinates.` select_adjust(self, tagOrId, index) `Adjust the end of the selection near the cursor of an item TAGORID to index.` select_clear(self) `Clear the selection if it is in this widget.` select_from(self, tagOrId, index) `Set the fixed end of a selection in item TAGORID to INDEX.` select_item(self) `Return the item which has the selection.` select_to(self, tagOrId, index) `Set the variable end of a selection in item TAGORID to INDEX.` tag_bind(self, tagOrId, sequence=None, func=None, add=None) `Bind to all items with TAGORID at event SEQUENCE a call to function FUNC. An additional boolean parameter ADD specifies whether FUNC will be called additionally to the other bound function or whether it will replace the previous function. See bind for the return value.` tag_lower(self, *args) `Lower an item TAGORID given in ARGS (optional below another item).` tag_raise(self, *args) `Raise an item TAGORID given in ARGS (optional above another item).` tag_unbind(self, tagOrId, sequence, funcid=None) `Unbind for all items with TAGORID for event SEQUENCE the function identified with FUNCID.` tkraise = tag_raise(self, *args) `Raise an item TAGORID given in ARGS (optional above another item).` type(self, tagOrId) `Return the type of the item TAGORID.` Methods inherited from Tkinter.BaseWidget: destroy(self) `Destroy this and all descendants widgets.` Methods inherited from Tkinter.Misc: __contains__(self, key) __getitem__ = cget(self, key) `Return the resource value for a KEY given as string.` __setitem__(self, key, value) __str__(self) `Return the window path name of this widget.` after(self, ms, func=None, *args) `Call function once after given time. MS specifies the time in milliseconds. FUNC gives the function which shall be called. Additional parameters are given as parameters to the function call. Return identifier to cancel scheduling with after_cancel.` after_cancel(self, id) `Cancel scheduling of function identified with ID. Identifier returned by after or after_idle must be given as first parameter.` after_idle(self, func, *args) `Call FUNC once if the Tcl main loop has no event to process. Return an identifier to cancel the scheduling with after_cancel.` bell(self, displayof=0) `Ring a display's bell.` bind(self, sequence=None, func=None, add=None) `Bind to this widget at event SEQUENCE a call to function FUNC. SEQUENCE is a string of concatenated event patterns. An event pattern is of the form <MODIFIER-MODIFIER-TYPE-DETAIL> where MODIFIER is one of Control, Mod2, M2, Shift, Mod3, M3, Lock, Mod4, M4, Button1, B1, Mod5, M5 Button2, B2, Meta, M, Button3, B3, Alt, Button4, B4, Double, Button5, B5 Triple, Mod1, M1. TYPE is one of Activate, Enter, Map, ButtonPress, Button, Expose, Motion, ButtonRelease FocusIn, MouseWheel, Circulate, FocusOut, Property, Colormap, Gravity Reparent, Configure, KeyPress, Key, Unmap, Deactivate, KeyRelease Visibility, Destroy, Leave and DETAIL is the button number for ButtonPress, ButtonRelease and DETAIL is the Keysym for KeyPress and KeyRelease. Examples are <Control-Button-1> for pressing Control and mouse button 1 or <Alt-A> for pressing A and the Alt key (KeyPress can be omitted). An event pattern can also be a virtual event of the form <<AString>> where AString can be arbitrary. This event can be generated by event_generate. If events are concatenated they must appear shortly after each other. FUNC will be called if the event sequence occurs with an instance of Event as argument. If the return value of FUNC is "break" no further bound function is invoked. An additional boolean parameter ADD specifies whether FUNC will be called additionally to the other bound function or whether it will replace the previous function. Bind will return an identifier to allow deletion of the bound function with unbind without memory leak. If FUNC or SEQUENCE is omitted the bound function or list of bound events are returned.` bind_all(self, sequence=None, func=None, add=None) `Bind to all widgets at an event SEQUENCE a call to function FUNC. An additional boolean parameter ADD specifies whether FUNC will be called additionally to the other bound function or whether it will replace the previous function. See bind for the return value.` bind_class(self, className, sequence=None, func=None, add=None) `Bind to widgets with bindtag CLASSNAME at event SEQUENCE a call of function FUNC. An additional boolean parameter ADD specifies whether FUNC will be called additionally to the other bound function or whether it will replace the previous function. See bind for the return value.` bindtags(self, tagList=None) `Set or get the list of bindtags for this widget. With no argument return the list of all bindtags associated with this widget. With a list of strings as argument the bindtags are set to this list. The bindtags determine in which order events are processed (see bind).` cget(self, key) `Return the resource value for a KEY given as string.` clipboard_append(self, string, **kw) `Append STRING to the Tk clipboard. A widget specified at the optional displayof keyword argument specifies the target display. The clipboard can be retrieved with selection_get.` clipboard_clear(self, **kw) `Clear the data in the Tk clipboard. A widget specified for the optional displayof keyword argument specifies the target display.` clipboard_get(self, **kw) `Retrieve data from the clipboard on window's display. The window keyword defaults to the root window of the Tkinter application. The type keyword specifies the form in which the data is to be returned and should be an atom name such as STRING or FILE_NAME. Type defaults to STRING, except on X11, where the default is to try UTF8_STRING and fall back to STRING. This command is equivalent to: selection_get(CLIPBOARD)` colormodel(self, value=None) `Useless. Not implemented in Tk.` columnconfigure = grid_columnconfigure(self, index, cnf={}, **kw) `Configure column INDEX of a grid. Valid resources are minsize (minimum size of the column), weight (how much does additional space propagate to this column) and pad (how much space to let additionally).` config = configure(self, cnf=None, **kw) `Configure resources of a widget. The values for resources are specified as keyword arguments. To get an overview about the allowed keyword arguments call the method keys.` configure(self, cnf=None, **kw) `Configure resources of a widget. The values for resources are specified as keyword arguments. To get an overview about the allowed keyword arguments call the method keys.` deletecommand(self, name) `Internal function. Delete the Tcl command provided in NAME.` event_add(self, virtual, *sequences) `Bind a virtual event VIRTUAL (of the form <<Name>>) to an event SEQUENCE such that the virtual event is triggered whenever SEQUENCE occurs.` event_delete(self, virtual, *sequences) `Unbind a virtual event VIRTUAL from SEQUENCE.` event_generate(self, sequence, **kw) `Generate an event SEQUENCE. Additional keyword arguments specify parameter of the event (e.g. x, y, rootx, rooty).` event_info(self, virtual=None) `Return a list of all virtual events or the information about the SEQUENCE bound to the virtual event VIRTUAL.` focus_displayof(self) `Return the widget which has currently the focus on the display where this widget is located. Return None if the application does not have the focus.` focus_force(self) `Direct input focus to this widget even if the application does not have the focus. Use with caution!` focus_get(self) `Return the widget which has currently the focus in the application. Use focus_displayof to allow working with several displays. Return None if application does not have the focus.` focus_lastfor(self) `Return the widget which would have the focus if top level for this widget gets the focus from the window manager.` focus_set(self) `Direct input focus to this widget. If the application currently does not have the focus this widget will get the focus if the application gets the focus through the window manager.` getboolean(self, s) `Return a boolean value for Tcl boolean values true and false given as parameter.` getvar(self, name='PY_VAR') `Return value of Tcl variable NAME.` grab_current(self) `Return widget which has currently the grab in this application or None.` grab_release(self) `Release grab for this widget if currently set.` grab_set(self) `Set grab for this widget. A grab directs all events to this and descendant widgets in the application.` grab_set_global(self) `Set global grab for this widget. A global grab directs all events to this and descendant widgets on the display. Use with caution - other applications do not get events anymore.` grab_status(self) `Return None, "local" or "global" if this widget has no, a local or a global grab.` grid_bbox(self, column=None, row=None, col2=None, row2=None) `Return a tuple of integer coordinates for the bounding box of this widget controlled by the geometry manager grid. If COLUMN, ROW is given the bounding box applies from the cell with row and column 0 to the specified cell. If COL2 and ROW2 are given the bounding box starts at that cell. The returned integers specify the offset of the upper left corner in the master widget and the width and height.` grid_columnconfigure(self, index, cnf={}, **kw) `Configure column INDEX of a grid. Valid resources are minsize (minimum size of the column), weight (how much does additional space propagate to this column) and pad (how much space to let additionally).` grid_location(self, x, y) `Return a tuple of column and row which identify the cell at which the pixel at position X and Y inside the master widget is located.` grid_propagate(self, flag=['_noarg_']) `Set or get the status for propagation of geometry information. A boolean argument specifies whether the geometry information of the slaves will determine the size of this widget. If no argument is given, the current setting will be returned.` grid_rowconfigure(self, index, cnf={}, **kw) `Configure row INDEX of a grid. Valid resources are minsize (minimum size of the row), weight (how much does additional space propagate to this row) and pad (how much space to let additionally).` grid_size(self) `Return a tuple of the number of column and rows in the grid.` grid_slaves(self, row=None, column=None) `Return a list of all slaves of this widget in its packing order.` image_names(self) `Return a list of all existing image names.` image_types(self) `Return a list of all available image types (e.g. phote bitmap).` keys(self) `Return a list of all resource names of this widget.` mainloop(self, n=0) `Call the mainloop of Tk.` nametowidget(self, name) `Return the Tkinter instance of a widget identified by its Tcl name NAME.` option_add(self, pattern, value, priority=None) `Set a VALUE (second parameter) for an option PATTERN (first parameter). An optional third parameter gives the numeric priority (defaults to 80).` option_clear(self) `Clear the option database. It will be reloaded if option_add is called.` option_get(self, name, className) `Return the value for an option NAME for this widget with CLASSNAME. Values with higher priority override lower values.` option_readfile(self, fileName, priority=None) `Read file FILENAME into the option database. An optional second parameter gives the numeric priority.` pack_propagate(self, flag=['_noarg_']) `Set or get the status for propagation of geometry information. A boolean argument specifies whether the geometry information of the slaves will determine the size of this widget. If no argument is given the current setting will be returned.` pack_slaves(self) `Return a list of all slaves of this widget in its packing order.` place_slaves(self) `Return a list of all slaves of this widget in its packing order.` propagate = pack_propagate(self, flag=['_noarg_']) `Set or get the status for propagation of geometry information. A boolean argument specifies whether the geometry information of the slaves will determine the size of this widget. If no argument is given the current setting will be returned.` quit(self) `Quit the Tcl interpreter. All widgets will be destroyed.` register = _register(self, func, subst=None, needcleanup=1) `Return a newly created Tcl function. If this function is called, the Python function FUNC will be executed. An optional function SUBST can be given which will be executed before FUNC.` rowconfigure = grid_rowconfigure(self, index, cnf={}, **kw) `Configure row INDEX of a grid. Valid resources are minsize (minimum size of the row), weight (how much does additional space propagate to this row) and pad (how much space to let additionally).` selection_clear(self, **kw) `Clear the current X selection.` selection_get(self, **kw) `Return the contents of the current X selection. A keyword parameter selection specifies the name of the selection and defaults to PRIMARY. A keyword parameter displayof specifies a widget on the display to use. A keyword parameter type specifies the form of data to be fetched, defaulting to STRING except on X11, where UTF8_STRING is tried before STRING.` selection_handle(self, command, **kw) `Specify a function COMMAND to call if the X selection owned by this widget is queried by another application. This function must return the contents of the selection. The function will be called with the arguments OFFSET and LENGTH which allows the chunking of very long selections. The following keyword parameters can be provided: selection - name of the selection (default PRIMARY), type - type of the selection (e.g. STRING, FILE_NAME).` selection_own(self, **kw) `Become owner of X selection. A keyword parameter selection specifies the name of the selection (default PRIMARY).` selection_own_get(self, **kw) `Return owner of X selection. The following keyword parameter can be provided: selection - name of the selection (default PRIMARY), type - type of the selection (e.g. STRING, FILE_NAME).` send(self, interp, cmd, *args) `Send Tcl command CMD to different interpreter INTERP to be executed.` setvar(self, name='PY_VAR', value='1') `Set Tcl variable NAME to VALUE.` size = grid_size(self) `Return a tuple of the number of column and rows in the grid.` slaves = pack_slaves(self) `Return a list of all slaves of this widget in its packing order.` tk_bisque(self) `Change the color scheme to light brown as used in Tk 3.6 and before.` tk_focusFollowsMouse(self) `The widget under mouse will get automatically focus. Can not be disabled easily.` tk_focusNext(self) `Return the next widget in the focus order which follows widget which has currently the focus. The focus order first goes to the next child, then to the children of the child recursively and then to the next sibling which is higher in the stacking order. A widget is omitted if it has the takefocus resource set to 0.` tk_focusPrev(self) `Return previous widget in the focus order. See tk_focusNext for details.` tk_menuBar(self, *args) `Do not use. Needed in Tk 3.6 and earlier.` tk_setPalette(self, *args, **kw) `Set a new color scheme for all widget elements. A single color as argument will cause that all colors of Tk widget elements are derived from this. Alternatively several keyword parameters and its associated colors can be given. The following keywords are valid: activeBackground, foreground, selectColor, activeForeground, highlightBackground, selectBackground, background, highlightColor, selectForeground, disabledForeground, insertBackground, troughColor.` tk_strictMotif(self, boolean=None) `Set Tcl internal variable, whether the look and feel should adhere to Motif. A parameter of 1 means adhere to Motif (e.g. no color change if mouse passes over slider). Returns the set value.` unbind(self, sequence, funcid=None) `Unbind for this widget for event SEQUENCE the function identified with FUNCID.` unbind_all(self, sequence) `Unbind for all widgets for event SEQUENCE all functions.` unbind_class(self, className, sequence) `Unbind for a all widgets with bindtag CLASSNAME for event SEQUENCE all functions.` update(self) `Enter event loop until all pending events have been processed by Tcl.` update_idletasks(self) `Enter event loop until all idle callbacks have been called. This will update the display of windows but not process events caused by the user.` wait_variable(self, name='PY_VAR') `Wait until the variable is modified. A parameter of type IntVar, StringVar, DoubleVar or BooleanVar must be given.` wait_visibility(self, window=None) `Wait until the visibility of a WIDGET changes (e.g. it appears). If no parameter is given self is used.` wait_window(self, window=None) `Wait until a WIDGET is destroyed. If no parameter is given self is used.` waitvar = wait_variable(self, name='PY_VAR') `Wait until the variable is modified. A parameter of type IntVar, StringVar, DoubleVar or BooleanVar must be given.` winfo_atom(self, name, displayof=0) `Return integer which represents atom NAME.` winfo_atomname(self, id, displayof=0) `Return name of atom with identifier ID.` winfo_cells(self) `Return number of cells in the colormap for this widget.` winfo_children(self) `Return a list of all widgets which are children of this widget.` winfo_class(self) `Return window class name of this widget.` winfo_colormapfull(self) `Return true if at the last color request the colormap was full.` winfo_containing(self, rootX, rootY, displayof=0) `Return the widget which is at the root coordinates ROOTX, ROOTY.` winfo_depth(self) `Return the number of bits per pixel.` winfo_exists(self) `Return true if this widget exists.` winfo_fpixels(self, number) `Return the number of pixels for the given distance NUMBER (e.g. "3c") as float.` winfo_geometry(self) `Return geometry string for this widget in the form "widthxheight+X+Y".` winfo_height(self) `Return height of this widget.` winfo_id(self) `Return identifier ID for this widget.` winfo_interps(self, displayof=0) `Return the name of all Tcl interpreters for this display.` winfo_ismapped(self) `Return true if this widget is mapped.` winfo_manager(self) `Return the window mananger name for this widget.` winfo_name(self) `Return the name of this widget.` winfo_parent(self) `Return the name of the parent of this widget.` winfo_pathname(self, id, displayof=0) `Return the pathname of the widget given by ID.` winfo_pixels(self, number) `Rounded integer value of winfo_fpixels.` winfo_pointerx(self) `Return the x coordinate of the pointer on the root window.` winfo_pointerxy(self) `Return a tuple of x and y coordinates of the pointer on the root window.` winfo_pointery(self) `Return the y coordinate of the pointer on the root window.` winfo_reqheight(self) `Return requested height of this widget.` winfo_reqwidth(self) `Return requested width of this widget.` winfo_rgb(self, color) `Return tuple of decimal values for red, green, blue for COLOR in this widget.` winfo_rootx(self) `Return x coordinate of upper left corner of this widget on the root window.` winfo_rooty(self) `Return y coordinate of upper left corner of this widget on the root window.` winfo_screen(self) `Return the screen name of this widget.` winfo_screencells(self) `Return the number of the cells in the colormap of the screen of this widget.` winfo_screendepth(self) `Return the number of bits per pixel of the root window of the screen of this widget.` winfo_screenheight(self) `Return the number of pixels of the height of the screen of this widget in pixel.` winfo_screenmmheight(self) `Return the number of pixels of the height of the screen of this widget in mm.` winfo_screenmmwidth(self) `Return the number of pixels of the width of the screen of this widget in mm.` winfo_screenvisual(self) `Return one of the strings directcolor, grayscale, pseudocolor, staticcolor, staticgray, or truecolor for the default colormodel of this screen.` winfo_screenwidth(self) `Return the number of pixels of the width of the screen of this widget in pixel.` winfo_server(self) `Return information of the X-Server of the screen of this widget in the form "XmajorRminor vendor vendorVersion".` winfo_toplevel(self) `Return the toplevel widget of this widget.` winfo_viewable(self) `Return true if the widget and all its higher ancestors are mapped.` winfo_visual(self) `Return one of the strings directcolor, grayscale, pseudocolor, staticcolor, staticgray, or truecolor for the colormodel of this widget.` winfo_visualid(self) `Return the X identifier for the visual for this widget.` winfo_visualsavailable(self, includeids=0) `Return a list of all visuals available for the screen of this widget. Each item in the list consists of a visual name (see winfo_visual), a depth and if INCLUDEIDS=1 is given also the X identifier.` winfo_vrootheight(self) `Return the height of the virtual root window associated with this widget in pixels. If there is no virtual root window return the height of the screen.` winfo_vrootwidth(self) `Return the width of the virtual root window associated with this widget in pixel. If there is no virtual root window return the width of the screen.` winfo_vrootx(self) `Return the x offset of the virtual root relative to the root window of the screen of this widget.` winfo_vrooty(self) `Return the y offset of the virtual root relative to the root window of the screen of this widget.` winfo_width(self) `Return the width of this widget.` winfo_x(self) `Return the x coordinate of the upper left corner of this widget in the parent.` winfo_y(self) `Return the y coordinate of the upper left corner of this widget in the parent.` Data and other attributes inherited from Tkinter.Misc: getdouble = <type 'float'> `float(x) -> floating point number Convert a string or number to a floating point number, if possible.` getint = <type 'int'> `int(x=0) -> int or long int(x, base=10) -> int or long Convert a number or string to an integer, or return 0 if no arguments are given. If x is floating point, the conversion truncates towards zero. If x is outside the integer range, the function returns a long instead. If x is not a number or if base is given, then x must be a string or Unicode object representing an integer literal in the given base. The literal can be preceded by '+' or '-' and be surrounded by whitespace. The base defaults to 10. Valid bases are 0 and 2-36. Base 0 means to interpret the base from the string as an integer literal. >>> int('0b100', base=0) 4` Methods inherited from Tkinter.Pack: forget = pack_forget(self) `Unmap this widget and do not use it for the packing order.` info = pack_info(self) `Return information about the packing options for this widget.` pack = pack_configure(self, cnf={}, **kw) `Pack a widget in the parent widget. Use as options: after=widget - pack it after you have packed widget anchor=NSEW (or subset) - position widget according to given direction before=widget - pack it before you will pack widget expand=bool - expand widget if parent size grows fill=NONE or X or Y or BOTH - fill widget if widget grows in=master - use master to contain this widget in_=master - see 'in' option description ipadx=amount - add internal padding in x direction ipady=amount - add internal padding in y direction padx=amount - add padding in x direction pady=amount - add padding in y direction side=TOP or BOTTOM or LEFT or RIGHT - where to add this widget.` pack_configure(self, cnf={}, **kw) `Pack a widget in the parent widget. Use as options: after=widget - pack it after you have packed widget anchor=NSEW (or subset) - position widget according to given direction before=widget - pack it before you will pack widget expand=bool - expand widget if parent size grows fill=NONE or X or Y or BOTH - fill widget if widget grows in=master - use master to contain this widget in_=master - see 'in' option description ipadx=amount - add internal padding in x direction ipady=amount - add internal padding in y direction padx=amount - add padding in x direction pady=amount - add padding in y direction side=TOP or BOTTOM or LEFT or RIGHT - where to add this widget.` pack_forget(self) `Unmap this widget and do not use it for the packing order.` pack_info(self) `Return information about the packing options for this widget.` Methods inherited from Tkinter.Place: place = place_configure(self, cnf={}, **kw) `Place a widget in the parent widget. Use as options: in=master - master relative to which the widget is placed in_=master - see 'in' option description x=amount - locate anchor of this widget at position x of master y=amount - locate anchor of this widget at position y of master relx=amount - locate anchor of this widget between 0.0 and 1.0 relative to width of master (1.0 is right edge) rely=amount - locate anchor of this widget between 0.0 and 1.0 relative to height of master (1.0 is bottom edge) anchor=NSEW (or subset) - position anchor according to given direction width=amount - width of this widget in pixel height=amount - height of this widget in pixel relwidth=amount - width of this widget between 0.0 and 1.0 relative to width of master (1.0 is the same width as the master) relheight=amount - height of this widget between 0.0 and 1.0 relative to height of master (1.0 is the same height as the master) bordermode="inside" or "outside" - whether to take border width of master widget into account` place_configure(self, cnf={}, **kw) `Place a widget in the parent widget. Use as options: in=master - master relative to which the widget is placed in_=master - see 'in' option description x=amount - locate anchor of this widget at position x of master y=amount - locate anchor of this widget at position y of master relx=amount - locate anchor of this widget between 0.0 and 1.0 relative to width of master (1.0 is right edge) rely=amount - locate anchor of this widget between 0.0 and 1.0 relative to height of master (1.0 is bottom edge) anchor=NSEW (or subset) - position anchor according to given direction width=amount - width of this widget in pixel height=amount - height of this widget in pixel relwidth=amount - width of this widget between 0.0 and 1.0 relative to width of master (1.0 is the same width as the master) relheight=amount - height of this widget between 0.0 and 1.0 relative to height of master (1.0 is the same height as the master) bordermode="inside" or "outside" - whether to take border width of master widget into account` place_forget(self) `Unmap this widget.` place_info(self) `Return information about the placing options for this widget.` Methods inherited from Tkinter.Grid: grid = grid_configure(self, cnf={}, **kw) `Position a widget in the parent widget in a grid. Use as options: column=number - use cell identified with given column (starting with 0) columnspan=number - this widget will span several columns in=master - use master to contain this widget in_=master - see 'in' option description ipadx=amount - add internal padding in x direction ipady=amount - add internal padding in y direction padx=amount - add padding in x direction pady=amount - add padding in y direction row=number - use cell identified with given row (starting with 0) rowspan=number - this widget will span several rows sticky=NSEW - if cell is larger on which sides will this widget stick to the cell boundary` grid_configure(self, cnf={}, **kw) `Position a widget in the parent widget in a grid. Use as options: column=number - use cell identified with given column (starting with 0) columnspan=number - this widget will span several columns in=master - use master to contain this widget in_=master - see 'in' option description ipadx=amount - add internal padding in x direction ipady=amount - add internal padding in y direction padx=amount - add padding in x direction pady=amount - add padding in y direction row=number - use cell identified with given row (starting with 0) rowspan=number - this widget will span several rows sticky=NSEW - if cell is larger on which sides will this widget stick to the cell boundary` grid_forget(self) `Unmap this widget.` grid_info(self) `Return information about the options for positioning this widget in a grid.` grid_remove(self) `Unmap this widget but remember the grid options.` location = grid_location(self, x, y) `Return a tuple of column and row which identify the cell at which the pixel at position X and Y inside the master widget is located.` Methods inherited from Tkinter.XView: xview(self, *args) `Query and change the horizontal position of the view.` xview_moveto(self, fraction) `Adjusts the view in the window so that FRACTION of the total width of the canvas is off-screen to the left.` xview_scroll(self, number, what) `Shift the x-view according to NUMBER which is measured in "units" or "pages" (WHAT).` Methods inherited from Tkinter.YView: yview(self, *args) `Query and change the vertical position of the view.` yview_moveto(self, fraction) `Adjusts the view in the window so that FRACTION of the total height of the canvas is off-screen to the top.` yview_scroll(self, number, what) `Shift the y-view according to NUMBER which is measured in "units" or "pages" (WHAT).`
class Item(__builtin__.object)
`` | `Represents a canvas item. When you create a canvas item, Tkinter returns an integer 'tag' that identifies the new item. To perform an operation on the item, you invoke a method on the canvas and pass the tag as a parameter. The Item class makes this interface more object-oriented: each Item object contains a canvas and a tag. When you invoke methods on the Item, it invokes methods on its canvas.`
| Methods defined here: __init__(self, canvas, tag) __str__(self) bbox(self) `Get the approximate bounding box for this item. Returns: BBox object in canvas coordinates.` bind(self, event, *args) `Applies a binding to this item. args can be (event, callback) or (event, callback, '+') For the event specifier, you can use Tkinter format, as in <Button-1>, or you can leave out the angle brackets.` cget(self, *args) `Looks up the value of the given option for this item.` config(self, **options) `Reconfigures this item with the given options.` coords(self, *args) `Gets or sets the canvas coordinates for this item.` delete(self) `Deletes this item from the canvas.` lift(self) `Raises this item to the top of the pile.` lower(self) `Lowers this item to the bottom of the pile.` move(self, dx, dy) `Moves this item by (dx, dy) in canvas coordinates.` move_coord(self, i, dx, dy) `Moves the ith coordinate by (dx, dy) in canvas coordinates.` replace_coord(self, i, coord) `Replaces the ith coordinate with the given coordinate.` scale(self, scale, offset) `Shifts and scales the coordinates of this item. Shifts by -(offset) and multiplies by (scale)` type(self) `Returns a string indicating the type of this item.` unbind(self, *args) `Removes bindings from this items.` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Point(__builtin__.list)
`` | `A list of coordinates. Because Point inherits __init__ from list, it makes a copy of the argument to the constructor.`
| Method resolution order: Point __builtin__.list __builtin__.object Methods defined here: copy lambda pos setx(pos, val) `# x and y can be accessed as attributes` sety(pos, val) Data descriptors defined here: x y Methods inherited from __builtin__.list: __add__(...) `x.__add__(y) <==> x+y` __contains__(...) `x.__contains__(y) <==> y in x` __delitem__(...) `x.__delitem__(y) <==> del x[y]` __delslice__(...) `x.__delslice__(i, j) <==> del x[i:j] Use of negative indices is not supported.` __eq__(...) `x.__eq__(y) <==> x==y` __ge__(...) `x.__ge__(y) <==> x>=y` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __gt__(...) `x.__gt__(y) <==> x>y` __iadd__(...) `x.__iadd__(y) <==> x+=y` __imul__(...) `x.__imul__(y) <==> x*=y` __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` __iter__(...) `x.__iter__() <==> iter(x)` __le__(...) `x.__le__(y) <==> x<=y` __len__(...) `x.__len__() <==> len(x)` __lt__(...) `x.__lt__(y) <==> x<y` __mul__(...) `x.__mul__(n) <==> x*n` __ne__(...) `x.__ne__(y) <==> x!=y` __repr__(...) `x.__repr__() <==> repr(x)` __reversed__(...) `L.__reversed__() -- return a reverse iterator over the list` __rmul__(...) `x.__rmul__(n) <==> n*x` __setitem__(...) `x.__setitem__(i, y) <==> x[i]=y` __setslice__(...) `x.__setslice__(i, j, y) <==> x[i:j]=y Use of negative indices is not supported.` __sizeof__(...) `L.__sizeof__() -- size of L in memory, in bytes` append(...) `L.append(object) -- append object to end` count(...) `L.count(value) -> integer -- return number of occurrences of value` extend(...) `L.extend(iterable) -- extend list by appending elements from the iterable` index(...) `L.index(value, [start, [stop]]) -> integer -- return first index of value. Raises ValueError if the value is not present.` insert(...) `L.insert(index, object) -- insert object before index` pop(...) `L.pop([index]) -> item -- remove and return item at index (default last). Raises IndexError if list is empty or index is out of range.` remove(...) `L.remove(value) -- remove first occurrence of value. Raises ValueError if the value is not present.` reverse(...) `L.reverse() -- reverse *IN PLACE*` sort(...) `L.sort(cmp=None, key=None, reverse=False) -- stable sort *IN PLACE*; cmp(x, y) -> -1, 0, 1` Data and other attributes inherited from __builtin__.list: __hash__ = None __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T`
class RotateTransform(Transform)
`` | `Rotates the coordinate system.`
| Method resolution order: RotateTransform Transform __builtin__.object Methods defined here: __init__(self, theta) `Rotates the coordinate system (theta) radians counterclockwise.` invert(self, p) trans(self, p) Methods inherited from Transform: invert_list(self, points) `Applies the inverse transform to the list of points.` trans_list(self, points, func=None) `Applies (func) to a list of points. If (func) is none, applies self.trans.` Data descriptors inherited from Transform: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class ScaleTransform(Transform)
`` | `Scales coordinates in the x and y directions. The origin is half a unit from the upper-left corner; the y axis points down.`
| Method resolution order: ScaleTransform Transform __builtin__.object Methods defined here: __init__(self, scale=[1, 1]) invert(self, p) trans(self, p) Methods inherited from Transform: invert_list(self, points) `Applies the inverse transform to the list of points.` trans_list(self, points, func=None) `Applies (func) to a list of points. If (func) is none, applies self.trans.` Data descriptors inherited from Transform: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class SwirlTransform(RotateTransform)
`` | `Rotates the coordinate system in proportion to distance from origin. Rotates (d) radians counterclockwise, where (d) is proportional to the distance from the origin`
| Method resolution order: SwirlTransform RotateTransform Transform __builtin__.object Methods defined here: invert(self, p) trans(self, p) Methods inherited from RotateTransform: __init__(self, theta) `Rotates the coordinate system (theta) radians counterclockwise.` Methods inherited from Transform: invert_list(self, points) `Applies the inverse transform to the list of points.` trans_list(self, points, func=None) `Applies (func) to a list of points. If (func) is none, applies self.trans.` Data descriptors inherited from Transform: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Transform(__builtin__.object)
`` | `Provides methods for transforming lists of coordinates. Subclasses should implement trans() and invert().`
| Methods defined here: invert_list(self, points) `Applies the inverse transform to the list of points.` trans_list(self, points, func=None) `Applies (func) to a list of points. If (func) is none, applies self.trans.` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`

Functions
`` |  | flatten(seq) `Concatenates the elements of seq. Given a list of lists, returns a new list that concatentes the elements of (seq). This just does one level of flattening; it is not recursive.` get_options(options, names) `Returns a dictionary with options for the given keys. Args: options: dict names: list of keys Returns: dict` gui_example() `Creates the same GUI as the previous function using Gui.py` main(script, function=None, *args) override(d, **kwds) `Adds entries from (kwds) to (d) even if they are already set.` pair(seq) `Returns a list of consecutive pairs from seq.` pairiter(seq) `Returns an iterator that yields consecutive pairs from seq.` pop_options(options, names) `Remove the given keys from options. Return a new dictionary with those key-value pairs. Args: options: dictionary names: list of keys. Returns: dict` remove_options(options, names) `Removes options from the dictionary. Modifies options. Args: options: dict names: list of keys` split_options(options) `Splits an options dictionary into into pack options and grid options. Anything left is assumed to be a widget option Args: options: dict Returns: tuple of (widget options, pack options, grid options)` tk_example() `Creates a simple GUI using only tkinter functions.` underride(d, **kwds) `Adds entries from (kwds) to (d) only if they are not already set.` widget_demo() `Demonstrates a variety of widgets.`

Data
`` |  | ALL = 'all' BOTTOM = 'bottom' E = 'e' END = 'end' LEFT = 'left' N = 'n' RIGHT = 'right' S = 's' TOP = 'top' W = 'w'